@@ -38,7 +38,7 @@ pub enum UniNodeLoadError {
     #[error("Not found loader for format '{0}'")]
     NotFoundLoader(String),
     #[error("Not found loader for file '{0}'")]
-    NotFoundStemLoader(String),
+    NotFoundBaseLoader(String),
     #[error("Failed extracts the extension of '{0}'")]
     FileExtension(String),
     #[error("{info} at line {} column {}", mark.line, mark.col)]
